/******************************************************************************/
/*         Hauptmodul fr das rfm02-Sendemodul an einer MSP430F169-MCU       */
/*                                                                            */                
/* T o o l - C h a i n                                                        */                
/* Entwicklungsumgebung: Rowley Crossworks for MSP430                         */                
/* Programmieradapter:   Olimex MSP430-JTAG                                   */                
/* MCU:                  MSP430F169                                         */                
/* Rechner:              Windows XP auf Atmel 4200+ X2                        */                
/*                                                                            */                
/* Programmablauf:       Alle 1 Sekunde sollen 5 Datenbytes gesendet werden.  */                
/*                       Hierzu wird alle 100ms ber Timer-A0 ein Interrupt   */                
/*                       generiert. In der Interrupt-Service-Routine werden   */                
/*                       diese Interrupts gezhlt und beim 10. ein Flag in    */                
/*                       einer globalen Variablen gesetzt.                    */                
/*                       Diese Variable wird im Main-Loop abgefragt und falls */                
/*                       das Flag darin gesetzt ist, 5 Datenbytes gesendet.   */               
/*                       Anschlieend wird das Modul wieder abgeschaltet, bzw.*/                
/*                       in seinen LowPowerMode versetzt, bis zur nchsten    */                
/*                       Datensendung.                                        */                
/*                                                                            */                
/*                                                                                  */                
/* Module: main.c, .h            : -> dieses Modul                                                                                 */                

/*         msp430F169_init.c/.h : Konfiguration der verwendeten MCU                */                

/*         rfm02_trans_init.c/.h : vollstndiges Konfigrationsmodul fr das         */                
/*                                 rfm02-Sendemodul in all einen Funktionalitten   */                
/*                                 zu initialisieren.                               */                

/*         rfm02_trans_cmd.c/.h  : Modul mit den fr das Sendemodul zur Verwendung  */                
/*                                 bentigten Handling-Funktionen                   */                
/*                                                                                  */                
/* Pin Description                                                                  */
/*                                                                                  */
/*    MSP-F169    Direction   RMF02-Module    Function  (MSP)                      */
/*                                                                                  */
/*    P1IN0(IR)     <---       /IRQ     Inport for the IRQ comming from rmf02       */
/*    P1OUT1.1      --->       FSK      Output for the data to bee transmitted      */
/*    P1OUT1.2      --->       /CS      Output for the Chip-Select ..               */
/*    P1OUT2.7      --->       SLK      Clock for the SPI-Interface of the ..       */
/*    P1OUT2.6      --->       SPI-SIMO Output (MOSI) for the SPI-Data-Inpute       */
/*                                                                                  */
/*
Anmerkung: Fr die Datenbertragung an die SPI-Schnittstelle des rfm02-Moduls wird
           hier zunchst nicht die MCU-interne SPI-Schnittstellen-Peripherie verwendet.
           Aus diesem Grund wird der SPI-Clock sowie der Datenausgang MOSI mit den
           beiden I/O-Ports P2.7 und P2.6 der MCU realisiert.

*/
/* Funktionen in diesem Modul:                                                      */
/*                                                                                  */
/*       main():    Hauptfunktion                                                   */
/*       ISR:       Interrupt Service Routine um alle 100ms einen Interrupt ber    */
/*                  den TimerA0 des MSP430F169 zu generieren.                      */
/*                                                                                  */
/* Ungereimtheiten:                                                                                 */
/*      - der Befehl Statusregister-Read ist nicht weiter erlutert                 */
//        Was soll denn da drin stehen ? Und vor allem, von wo soll der gelesen
//        werden ?
//      - nIRQ ist kein lowaktiver Interrupt-Request-Ausgang, sondern ein highaktiver
//        DataClockAusgang um auf den FSK-In-Port zu schreiben !!!
//      - Die Doku ist leider nur mit "ungengend" zu betiteln, da zu unvollstndig
//        Es wird nicht erlutert, wie die Befehle gehandhabt werden mssen. Es funktionieren
//        einige Befehle nicht, oder vielleicht nur ein einer bestimmten Reihenfolge
//        oder Initialisierung, die aber nicht verraten wird.
//      - Frequenzeinstellung :
//        Die Werte drfen dabei von 0x0060 bis maximal 0x0F3F liegen. Auerhalb
//        dieses Bereiches springt die Sendefrequenz auf ihren Band-Grundwert,
//        d.h. 435 bzw. 870 MHz  bzw. 360 MHz bzw. 915MHz
//      - Die Bandumschaltung ber b0 und b1 im Kontroll Register ( Bit11 und Bit12)
//        ist in manchen Dokumenatationen nicht erwhnt. Funktioniert aber.
//        Auch lsst sich das Modul ber diese Bits auf das 360MHz-Band einstellen !
//      - Die Baudrateneinstellung geht noch viel besser, nmlich auch bis 172 kbps
//        und sogar 445 kbps !!!
//
//
/* Fazit:                                                                           */
/*      Ohne Oszi und Frequenzzhler und viel viel Zeit und Nerven                  */
/*      ist der Kampf mit dem Modul nicht zu empfehlen                              */
/*                                                                                  */
/*                                                                                  */
/* Autor: Hr.JSchroeder@web.de     01/2012                                          */                
/************************************************************************************/


/*------------------------------------------------------------------*/
/*    INCLUDES                                                      */
/*------------------------------------------------------------------*/

#include <__cross_studio_io.h>

#include "includes.h"  // Bindet ber eigenen File  a l l e  bentigten
                       // Headerfiles ein, d.h. verknpft  das Modul
                       // main.c mit den anderen Modulen

/*------------------------------------------------------------------*/
/*    DEFINES (falls nicht in eigener Header-Datei  defines.h)      */
/*------------------------------------------------------------------*/


/*------------------------------------------------------------------*/
/*    FUNCTION PROTOTYPES  ( falls nicht in Header-Files *.h, die   */
/*                           ber includes.h hier eingebunden sind.)*/
/*------------------------------------------------------------------*/


/*------------------------------------------------------------------*/
/*    GLOBAL VARIABLES      ( falls nicht in Variablen-Modul )      */
/*------------------------------------------------------------------*/
unsigned char global_FlagVari;

/*------------------------------------------------------------------*/
/*    FUNCTIONS      ( falls nicht in externen bereichsspezifischen Modulen ) */
/*------------------------------------------------------------------*/


/*------------------------------------------------------------------*/
/*    Main Function                                                 */
/*------------------------------------------------------------------*/

void main( void )
{
const char TX_DATA=0xAA;
char       n;


  // Stop watchdog timer to prevent time out reset
  WDTCTL = WDTPW + WDTHOLD;       // Stoppt den WatchDog-Timer. Ansonsten kommt der Prozessor
                                  // nicht aus dem Reset.

  Init_MSP430F169();             // Initialisiert und konfiguriert die ntigen MSP430-Ports
  Init_RFM02_Transmit_Module_Continous_Mode(); // Initialisiert/konfiguriert das Sendemodul

  while(1){

    if ( global_FlagVari && BIT0 ){             // Wird alle 10 x 100ms ausgefhrt

P1DIR = 0xFF;   // Special thing... to make Sleep-Command working ...??? but it works
P1DIR &= ~BIT0; // Not needet with a MSP430F2013 with internal Pullup Resistor

      RFM02_CMD_Switch_On();
      for(n=5;n>0;n--)RFM02_CMD_Transmit_DataByte( TX_DATA ); // send 5 Byte in Auto-Mode
      RFM02_CMD_Switch_Off();

      P5OUT^=BIT0;            // Toggel eine LED, damit ich wei, wo ich bin ...

      global_FlagVari &= ~BIT0;
      
    } 
  }
}

/*------------------------------------------------------------------*/
/*    INTERRUPTS      ( falls nicht in irq.c/.h)                    */
/*------------------------------------------------------------------*/
// Timer A0 interrupt service routine
// ACHTUNG: Breakpoints knnen hier nur gesetzt werden, wenn als Target
// eine Hardware am Programmieradapter hngend zur Verfgung steht. (TI MSP-FET430PIF)
// Nur dann werden diese Breakpoints aktiv.
#pragma vector=TIMERA0_VECTOR
__interrupt void Timer_A0 (void)
{
static unsigned char IR_Cntr=0;
char n;  
  CCR0 += 12500;              // This Offset is added to the value of the CCR0.
  IR_Cntr +=1;                // With 1MHz Clock Source this is exactly 100ms to

  if ( IR_Cntr >=10 ){        // As I need a task execution every second, I count 10 IR calls.
     global_FlagVari |= BIT0; // This vari is tested in Mainloop to do something
     IR_Cntr = 0;
  }
}                  
