/******************************************************************************/
/*         Programm-Modul mit Initialisierungsfunktionen fr die MCU          */
/*                                                                            */                
/*                                                                            */                
/* Funktionen:    Init_MSP430F169(); --> MainClock, Ports, Modul-Interface,   */
/*                                       TimerA0 in Compare-Mode              */                
/*                Init_MSP430F2013_SPI_Port(); // nicht codiert               */                
/*                                                                            */                
/*                                                                            */                
/*                                                                            */                
/*                                                                            */                
/******************************************************************************/

/*------------------------------------------------------------------*/
/*    INCLUDES                                                      */
/*------------------------------------------------------------------*/

#include "includes.h"

/*------------------------------------------------------------------*/
/*    FUNCTIONS      ( falls nicht in externen bereichsspezifischen Modulen ) */
/*------------------------------------------------------------------*/

void Init_MSP430F169(void)
{
// Setting System Clock ( DCO ) to 1.000 MHz
// This is made by configuring 2 Registers BCSCTL1 and DCOCTL
// with DCO0..DCO2 (DCOCTL) and RSEL0..RSEL3 (BCSCTL1)
// For Example: DCOCTL |= DCO0 + DCO1; // DCO=3
//           BCSCTL1   |= RSEL2 + RSEL1 + RSEL0; // RSEL=7
//With the following pre-defines ...
//#define CALDCO_1MHZ_          (0x10..)  /* DCOCTL  Calibration Data for 1MHz */
//const sfrb CALDCO_1MHZ      = CALDCO_1MHZ_;
//#define CALBC1_1MHZ_          (0x10..)  /* BCSCTL1 Calibration Data for 1MHz */
//const sfrb CALBC1_1MHZ      = CALBC1_1MHZ_;

// CALDCO_1MHZ
// The MSP430F169 runs at about 1 MHz MainClock from the internal DCO by PowerUpClear.
// --> so we do not need to adjust the frequency for the SMCK

/*******************************************************************************/
/*    Pin Description                                                          */
/*                                                                             */
/*    MSP-F2013    Direction   RMF02-Module    Function  (MSP)                 */
/*                                                                             */
/*    P1IN0(IR)     <---       /IRQ     Inport for the IRQ comming from rmf02  */
/*    P1OUT1.1      --->       FSK      Output for the data to bee transmitted */
/*    P1OUT1.2      --->       /CS      Output for the Chip-Select ..          */
/*    P1OUT2.7      --->       SLK      Clock for the SPI-Interface of the ..  */
/*    P1OUT2.6(SDO) --->       SPI-SIMO Output (MOSI) for the SPI-Data-Inpute  */
/*                                                                             */
/*******************************************************************************/

// I/O-Ports  *******************************************************************

// Port 1
  P1DIR = 0xFF; P1DIR &= ~BIT0;   // P1.0 is the input from the /IRQ from the module
  P1SEL = 0x00; 

// Port 2     Setting P2.6 and P2.7 as  I/O-Ports
  P2DIR = 0xFF;  
  P2SEL  = 0x00; 

// Port 5
  P5DIR = 0xFF;
  P5SEL = 0x00; 

// Modul Interface  via Macros ( in *.h )
   SCK_low();
   SDI_low();
   FSK_high();
   nCS_high();

// Timer A    It is used to generate an IR every 100ms.  Every second the transmit module
//            sends its few bytes and goes to sleep again.
// use    SystemClock /  8  and Clear TAR
  TACTL |= TACLR;             // Clear TAR, Clock-Devider and Count-Mode
  TACTL |= TASSEL_2  +  ID_3; // Set Clocksource to SMCLK (1MHz), Divider /8
  CCR0 = 12500;               // Set Capture Compare Register to its 1st value
  CCTL0  = CCIE;              // Enable Compare-Interrupt, CCR0 == TAR ?
  TACTL |= MC_2;              // Start Timer_A in continuous mode
  _EINT();                    // Enable Interrupts, setting GIE-Bit in it's register

// Interrupt Handling
//  _BIS_SR(GIE);             // General Interrupt Enable, the same as _EINT();


// SPI-Port
  Init_MSP430F2013_SPI_Port();
}

// SPI-Port
/*
Control Registers                         16-Bit   MSB       LSB
 USI control register                     USICTL   USICTL1   USICTL0
 USI clock and counter control register   USICCTL  USICNT    USICKCTL
 USI shift register                       USISR    USISRH    USISRL

USICTL    15      14     13       12    11    10      9         8
         USICKPH USII2C USISTTIE USIIE USIAL USISTP USISTTIFG USIIFG  // 0x01 after PowerUpClear
USICKPH Bit 15 Clock phase select
        0 Data is changed on the first SCLK edge and captured on the following edge.
        1 Data is captured on the first SCLK edge and changed on the following edge.
USII2C Bit14 I2C mode enable
       0 I2C mode disabled
       1 I2C mode enabled
USISTTIE Bit 13 START condition interrupt-enable
         0 Interrupt on START condition disabled
         1 Interrupt on START condition enabled
USIIE Bit 12 USI counter interrupt enable
      0 Interrupt disabled
      1 Interrupt enabled
USIAL Bit 11 Arbitration lost
      0 No arbitration lost condition
      1 Arbitration lost
USISTP Bit 10 STOP condition received. USISTP is automatically cleared if USICNTx is loaded with 
              a value > 0 when USIIFGCC = 0.
              0 No STOP condition received
              1 STOP condition received
USISTTIFG Bit 9 START condition interrupt flag
          0 No START condition received. No interrupt pending.
          1 START condition received. Interrupt pending.
USIIFG Bit 8 USI counter interrupt flag. Set when the USICNTx = 0. Automatically cleared if 
             USICNTx is loaded with a value > 0 when USIIFGCC = 0.
             0 No interrupt pending
             1 Interrupt pending

          7       6      5        4     3     2      1         0
         USIPE7 USIPE6 USIPE5 USILSB USIMST USIGE USIOE USISWRST      // 0x01 after PowerUpClear

USIPE7 Bit 7 USI SDI/SDA port enable. Input in SPI mode, input or open drain output in I2C mode.
           0 USI function disabled
           1 USI function enabled
USIPE6 Bit 6 USI SDO/SCL port enable. Output in SPI mode, input or open drain output in I2C mode.
           0 USI function disabled
           1 USI function enabled
USIPE5 Bit 5 USI SCLK port enable. Input in SPI slave mode, or I2C mode, output in SPI master mode.
           0 USI function disabled
           1 USI function enabled
USILSB Bit 4 LSB first select. This bit controls the direction of the receive and transmit shift register.
           0 MSB first
           1 LSB first
USIMST Bit 3 Master select
           0 Slave mode
           1 Master mode
USIGE Bit 2 Output latch control
            0 Output latch enable depends on shift clock
            1 Output latch always enabled and transparent
USIOE Bit 1 Data output enable
            0 Output disabled
            1 Output enabled
USISWRST Bit 0 USI software reset
             0 USI released for operation.
             1 USI logic held in reset state.
------------------------------------------------------------------------------------------------
USICCTL    15      14     13         12    11    10      9         8  // 0x00 after PUC
        USISCLREL USI16B USIIFGCC |          USICNTx

USISCLREL :  SCL release. The SCL line is released from low to idle. USISCLREL is cleared if 
             a START condition is detected.
               0 SCL line is held low if USIIFG is set
               1 SCL line is released
USI16B    :  16-bit shift register enable
             0 8-bit shift register mode. Low byte register USISRL is used.
             1 16-bit shift register mode. Both high and low byte registers USISRL and USISRH 
               are used. USISR addresses all 16 bits simultaneously.
USIIFGCC  :  USI interrupt flag clear control. When USIIFGCC = 1 the USIIFG will not be cleared 
             automatically when USICNTx is written with a value > 0.
               0 USIIFG automatically cleared on USICNTx update
               1 USIIFG is not cleared automatically
USICNTx   :  USI bit count. The USICNTx bits set the number of bits to be received or transmitted.


            7       6      5        4     3     2      1         0    // 0x00 after PUC
                 USIDIVx       |        USISSELx   |  USICKPL USISWCLK
USIDIVx Bits 7-5 Clock divider select
000 Divide by 1
001 Divide by 2
010 Divide by 4
011 Divide by 8
100 Divide by 16
101 Divide by 32
110 Divide by 64
111 Divide by 128

USISSELx Bits 4-2 Clock source select. Not used in slave mode.
000 SCLK (Not used in SPI mode)
001 ACLK
010 SMCLK
011 SMCLK
100 USISWCLK bit
101 TACCR0
110 TACCR1
111 TACCR2 (Reserved on MSP430F20xx devices)

USICKPL Bit 1  Clock polarity select
               0 Inactive state is low
               1 Inactive state is high
USISWCLK Bit 0 Software clock
               0 Input clock is low
               1 Input clock is high
-----------------------------------------------------------------------------------------------

USISR    16-Bit Shift Register

-----------------------------------------------------------------------------------------------
Example:
  USICTL0 |= USIPE7 +  USIPE6 + USIPE5 + USIMST + USIOE; // Port, SPI master
                                       // SDI/SDA port enable (USIPE7)
                                       // SDO/SCL port enable (USIPE6)
                                       // USI SCLK port enable (USIPE5)
                                       // Master-Mode enabled (USIMST)
                                       // Data Output Enable (USIOE)

  USICTL1 |= USIIE;                     // USI counter interrupt enable, flag remains set

  USICKCTL = USIDIV_4 + USISSEL_2;      // Clock source select (SMCLK), Divider Select /16

  USICTL0 &= ~USISWRST;                 // USI Software Reset, USI released for operation

  USISRL = P1IN;                        // init-load data


*/
void Init_MSP430F2013_SPI_Port( void ){
//  USICTL |=  (USICKPH<<8);    // Clock Phase select, 0 Data is changed on the first SCLK edge 
                                // and captured on the following edge
//  USICTL |= (USII2C<<8);      // I2C mode enable
//  USICTL |= (USISTTIE<<8);    // START condition interrupt-enable 
// ???  USICTL |= (USIIE<<8);         //  12 USI counter interrupt enable
//  USICTL |= (USIAL<<8);       //  Arbitration lost, 0 No arbitration lost condition
//  USICTL |= (USISTP<<8);        //  STOP condition received, no Stop condition
//  USICTL |= (USISTTIFG<<8);     //  No START condition received
//  USICTL |= (USIIFG<<8);        //  USI counter interrupt flag

//  USICTL |= USIPE7;             //  SDI Port enabled   not used, not present in module
/*
  USICTL |= USIPE6;             //  SDO Port enabled
  USICTL |= USIPE5;             //  USI SCLK Port enabled
//  USICTL |= USILSB;           //  LSB first select, 0 --> MSB first
  USICTL |= USIMST;             //  Master Mode Select 1 --> MSP430 is master
//  USICTL |= USIGE;              //  Output latch control
  USICTL |= USIOE;              //  Data Output Enable

//  USICCTL |= (USISCLREL<<8);  // SCL release... see above
  USICCTL |= (USI16B<<8);       // 16-Bit Shift Register enabled
//  USICCTL |= (USIIFGCC<<8);     // USI interrupt flag clear control... see above      
//  USICCTL |= (USICNT4<<8);    // USI bit count. The USICNTx bits set the number of bits to be received or transmitted.
                                // USICNT4 --> 32 Bit  ... for example
  USICCTL |= USIDIV_4;           // pre-divider 
  USICCTL |= USISSEL_2;          // SCL-Source Select, SMCLK
*/
// USICCTL |= USICKPL;            // Clock polarity select, 0 Inactive state is low
// USICCTL |= USISWCLK;              // Software Clock

//  USICTL |= USISWRST;           //  USI Software Reset, USI released for operation
}


          

