#ifndef RFM02_CMD_h
#define RFM02_CMD_h

/******************************************************************************/
/*    Pin Description                                                         */
/*                                                                            */
/*    MSP-F2013    Direction   RMF02-Module    Function  (MSP)                */
/*                                                                            */
/*    P1IN (IR)     <---       /IRQ            Inport for the IRQ comming     */
/*    P1OUT1.1      --->       FSK             Output for the data            */
/*    P1OUT1.2      --->       /CS             Output for the Chip-Select     */
/*    P1OUT2.7      --->       SLK             Clock for the SPI-Interface    */
/*    P1OUT2.6      --->       SDI       Output (MOSI) for the SPI-Data-Input */
/*                                                                            */
/******************************************************************************/


/*    Working Commands                                                        */

/******************************************************************************/
/*    Sleep-Command-Register  C400hex                                         */
/*                                                                            */
/*    Bits:  15  14  13  12  11  10   9   8   7   6   5   4   3   2   1   0   */
/*            1   1   0   0   0   1   0   0  s7  s6  s5  s4  s3  s2  s1  s0   */
/*                                                                            */
/*     If crystal oscillator, synthesizer and power amplifier are auto-       */
/*     controlled via the a0 and a1 bit in the Power Management Register      */
/*     This command will stop them and finally stop the oscillator after       */
/*     S periods of the system clock. So S ranges from 0 .. 255 periods       */
/*                                                                            */
/******************************************************************************/
#define CMD_SLEEP               0xC400

// for example
#define CMD_SLEEP_AFTER_255_PERIODS  0xFF

/******************************************************************************/
/*    Wake-Up-Timer-Command-Register  E000hex                                 */
/*                                                                            */
/*    Bits:  15  14  13  12  11  10   9   8   7   6   5   4   3   2   1   0   */
/*            1   1   1  r4  r3  r2  r1  r0  m7  m6  m5  m4  m3  m2  m1  m0   */
/*                                                                            */
/*    The wake-up-timer-period is controlled by m7..m0                        */
/*                                                                            */
/*    Twu = M * 2 ms                                                          */
/*                                                                            */
/*    So Twu ranges from 0ms .. 510ms                                         */
/*                                                                            */
/*    For continual operation the et-bit in the Power-Management-Register     */
/*    must be cleared and set, and a0 and a1 must be cleared.                 */
/*                                                                            */
/*    r0..r4  ?????  not documented, we assume they to be 0                   */
/*                                                                            */
/******************************************************************************/
#define CMD_WAKEUP              0xE000

// for example  Twu = 510ms
#define CMD_WAKEUP_AFTER_510_MS 0xFF

/******************************************************************************/
/*    Data Transmit Command                                                   */
/*                                                                            */
/*    Bits:   7   6   5   4   3   2   1   0                                   */
/*            1   1   0   0   0   1   1   0                                   */
/*                                                                            */
/*    This command indicates that the following data on SDI is transmit data. */
/*    Transmitting stops again when /SEL turns high again.                    */
/*                                                                            */
/******************************************************************************/
#define CMD_TRANSMIT_DATA    0xC6

/******************************************************************************/
/*    Status-Register-Read-Command                                            */
/*                                                                            */
/*    Bits:  15  14  13  12  11  10   9   8   7   6   5   4   3   2   1   0   */
/*            1   1   0   0   1   1   0   0   0   0   0   0   0   0   0   0   */
/*                                                                            */
/*    This command is to read internal status register.                       */
/*                                                                            */
/*    The output starts with the 8th clock of SCK.                            */
/*                                                                            */
/*    Not further documented, so not usable.    <-----------                  */
/*                                                                            */
/*    At least we need to know what status bit in the register are, <------   */
/*    as well as to know from what output to read !!!!                                                                        */
/*                                                                            */
/******************************************************************************/

void RFM02_CMD_Transmit_DataByte(char);         // 8-Bit-Transmission via FSK-Input
void RFM02_CMD_Transmit_DataWord(int);          // 16-Bit-Transmission via FSK-Input

void RFM02_CMD_Sleep(void);            // works only in Auto-Mode
void RFM02_CMD_TransmissionWakeUp(void);// 

void RFM02_CMD_Switch_On(void);
void RFM02_CMD_Switch_Off(void);

void Wait_100ms(int);


#endif
